==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/DesktopMFAEnforceNumberMatchingChallengeOrgSetting.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DesktopMFAEnforceNumberMatchingChallengeOrgSetting
 */
@JsonPropertyOrder({
        DesktopMFAEnforceNumberMatchingChallengeOrgSetting.JSON_PROPERTY_DESKTOP_M_F_A_ENFORCE_NUMBER_MATCHING_CHALLENGE_ENABLED })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class DesktopMFAEnforceNumberMatchingChallengeOrgSetting implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DESKTOP_M_F_A_ENFORCE_NUMBER_MATCHING_CHALLENGE_ENABLED = "desktopMFAEnforceNumberMatchingChallengeEnabled";
    private Boolean desktopMFAEnforceNumberMatchingChallengeEnabled = false;

    public DesktopMFAEnforceNumberMatchingChallengeOrgSetting() {
    }

    public DesktopMFAEnforceNumberMatchingChallengeOrgSetting desktopMFAEnforceNumberMatchingChallengeEnabled(
            Boolean desktopMFAEnforceNumberMatchingChallengeEnabled) {

        this.desktopMFAEnforceNumberMatchingChallengeEnabled = desktopMFAEnforceNumberMatchingChallengeEnabled;
        return this;
    }

    /**
     * Indicates whether or not the Desktop MFA Enforce Number Matching Challenge push notifications feature is enabled
     *
     * @return desktopMFAEnforceNumberMatchingChallengeEnabled
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates whether or not the Desktop MFA Enforce Number Matching Challenge push notifications feature is enabled")
    @JsonProperty(JSON_PROPERTY_DESKTOP_M_F_A_ENFORCE_NUMBER_MATCHING_CHALLENGE_ENABLED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getDesktopMFAEnforceNumberMatchingChallengeEnabled() {
        return desktopMFAEnforceNumberMatchingChallengeEnabled;
    }

    @JsonProperty(JSON_PROPERTY_DESKTOP_M_F_A_ENFORCE_NUMBER_MATCHING_CHALLENGE_ENABLED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDesktopMFAEnforceNumberMatchingChallengeEnabled(
            Boolean desktopMFAEnforceNumberMatchingChallengeEnabled) {
        this.desktopMFAEnforceNumberMatchingChallengeEnabled = desktopMFAEnforceNumberMatchingChallengeEnabled;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DesktopMFAEnforceNumberMatchingChallengeOrgSetting desktopMFAEnforceNumberMatchingChallengeOrgSetting = (DesktopMFAEnforceNumberMatchingChallengeOrgSetting) o;
        return Objects.equals(this.desktopMFAEnforceNumberMatchingChallengeEnabled,
                desktopMFAEnforceNumberMatchingChallengeOrgSetting.desktopMFAEnforceNumberMatchingChallengeEnabled);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(desktopMFAEnforceNumberMatchingChallengeEnabled);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DesktopMFAEnforceNumberMatchingChallengeOrgSetting {\n");
        sb.append("    desktopMFAEnforceNumberMatchingChallengeEnabled: ")
                .append(toIndentedString(desktopMFAEnforceNumberMatchingChallengeEnabled)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/DesktopMFAEnforceNumberMatchingChallengeOrgSetting.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DesktopMFAEnforceNumberMatchingChallengeOrgSetting
 */
@JsonPropertyOrder({
        DesktopMFAEnforceNumberMatchingChallengeOrgSetting.JSON_PROPERTY_DESKTOP_M_F_A_ENFORCE_NUMBER_MATCHING_CHALLENGE_ENABLED })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class DesktopMFAEnforceNumberMatchingChallengeOrgSetting implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DESKTOP_M_F_A_ENFORCE_NUMBER_MATCHING_CHALLENGE_ENABLED = "desktopMFAEnforceNumberMatchingChallengeEnabled";
    private Boolean desktopMFAEnforceNumberMatchingChallengeEnabled = false;

    public DesktopMFAEnforceNumberMatchingChallengeOrgSetting() {
    }

    public DesktopMFAEnforceNumberMatchingChallengeOrgSetting desktopMFAEnforceNumberMatchingChallengeEnabled(
            Boolean desktopMFAEnforceNumberMatchingChallengeEnabled) {

        this.desktopMFAEnforceNumberMatchingChallengeEnabled = desktopMFAEnforceNumberMatchingChallengeEnabled;
        return this;
    }

    /**
     * Indicates whether or not the Desktop MFA Enforce Number Matching Challenge push notifications feature is enabled
     *
     * @return desktopMFAEnforceNumberMatchingChallengeEnabled
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates whether or not the Desktop MFA Enforce Number Matching Challenge push notifications feature is enabled")
    @JsonProperty(JSON_PROPERTY_DESKTOP_M_F_A_ENFORCE_NUMBER_MATCHING_CHALLENGE_ENABLED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getDesktopMFAEnforceNumberMatchingChallengeEnabled() {
        return desktopMFAEnforceNumberMatchingChallengeEnabled;
    }

    @JsonProperty(JSON_PROPERTY_DESKTOP_M_F_A_ENFORCE_NUMBER_MATCHING_CHALLENGE_ENABLED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDesktopMFAEnforceNumberMatchingChallengeEnabled(
            Boolean desktopMFAEnforceNumberMatchingChallengeEnabled) {
        this.desktopMFAEnforceNumberMatchingChallengeEnabled = desktopMFAEnforceNumberMatchingChallengeEnabled;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DesktopMFAEnforceNumberMatchingChallengeOrgSetting desktopMFAEnforceNumberMatchingChallengeOrgSetting = (DesktopMFAEnforceNumberMatchingChallengeOrgSetting) o;
        return Objects.equals(this.desktopMFAEnforceNumberMatchingChallengeEnabled,
                desktopMFAEnforceNumberMatchingChallengeOrgSetting.desktopMFAEnforceNumberMatchingChallengeEnabled);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(desktopMFAEnforceNumberMatchingChallengeEnabled);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DesktopMFAEnforceNumberMatchingChallengeOrgSetting {\n");
        sb.append("    desktopMFAEnforceNumberMatchingChallengeEnabled: ")
                .append(toIndentedString(desktopMFAEnforceNumberMatchingChallengeEnabled)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
